//--------------------------------------------------------------
// File     : stm32_ub_lcd_n95_8gb.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_LCD_N958GB_H
#define __STM32F4_UB_LCD_N958GB_H

//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_fsmc.h"


//--------------------------------------------------------------
// Standard Farbwerte
// 24bit Farbwert (R8G8B8)
// Red   (8bit) -> Bit23-Bit16
// Green (8bit) -> Bit15-Bit8
// Blue  (8bit) -> Bit7-Bit0
//--------------------------------------------------------------
#define  RGB_COL_BLACK          0x000000
#define  RGB_COL_BLUE           0x0000FF
#define  RGB_COL_GREEN          0x00FF00
#define  RGB_COL_RED            0xFF0000
#define  RGB_COL_WHITE          0xFFFFFF

#define  RGB_COL_CYAN           0x00FFFF
#define  RGB_COL_MAGENTA        0xFF00FF
#define  RGB_COL_YELLOW         0xFFFF00

#define  RGB_COL_GREY           0xCCCCCC


//--------------------------------------------------------------
// Display Mode
//--------------------------------------------------------------
typedef enum {
  PORTRAIT =0,
  LANDSCAPE
}LCD_MODE_t;
LCD_MODE_t  LCD_DISPLAY_MODE;


//--------------------------------------------------------------
// Display Fenster Settings
//--------------------------------------------------------------
typedef struct {
  uint16_t xstart;
  uint16_t ystart;
  uint16_t xend;
  uint16_t yend;
  uint32_t pixel;
}LCD_WINDOW_t;
LCD_WINDOW_t LCD_WINDOW;


//--------------------------------------------------------------
// Adressen vom FSMC um auf das Display zuzugreifen
// Bank   = Bank-1 / PSRAM-1        => BaseAdr 0x60000000
// RS-Pin = PE3=FSMC_A19 = BitNr 19 => Offset  0x00100000
// (siehe Seite 1316+1317 vom Referenz Manual)
//--------------------------------------------------------------
#define LCD_REG  (*((volatile unsigned short *) 0x60000000)) // RS = 0
#define LCD_RAM  (*((volatile unsigned short *) 0x60100000)) // RS = 1
#define LCD_RAM_ADR   0x60100000  // Adresse vom RAM

//--------------------------------------------------------------
// Defines vom Display
//--------------------------------------------------------------
#define  LCD_N95_ID  0x2991     // ID vom N95-8GB
#define  LCD_MAXX  240          // Pixel in X-Richtung
#define  LCD_MAXY  320          // Pixel in Y-Richtung
#define  LCD_PIXEL  LCD_MAXX*LCD_MAXY
#define  LCD_N95_PAUSE     50000
#define  LCD_N95_FSMC_AST  0 // AdressSetupTime [0]
#define  LCD_N95_FSMC_DST  6 // DataSetupTime [6]
#define  LCD_N95_PORTRAIT  0x60  // Mode = Portrait
#define  LCD_N95_LANDSCAPE 0x40  // Mode = Landscape



//--------------------------------------------------------------
// Register Adressen vom Display-Controller
//--------------------------------------------------------------
#define  LCD_RDDID    0x04   // Display-ID
#define  LCD_SLPOUT   0x11   // Sleep Out
#define  LCD_NORON    0x13   // Normal Display Mode On
#define  LCD_INVOFF   0x20   // Display Inversion Off
#define  LCD_DISPON   0x29   // Display ON
#define  LCD_CASET    0x2A   // Column Address Set
#define  LCD_RASET    0x2B   // Row Address Set
#define  LCD_RAMWR    0x2C   // Memory Write
#define  LCD_MADCTR   0x36   // Memory Data Access Control
#define  LCD_IDMOFF   0x38   // Idle Mode Off
#define  LCD_COLMOD   0x3A   // Interface Pixel Format
#define  LCD_WRDISBV  0x51   // Write Display Brightness
#define  LCD_WRCTRLD  0x53   // Write CTRL Display
#define  LCD_WRCABC   0x55   // Write Content Adaptive Brightness




//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
ErrorStatus UB_LCD_Init(void);
void UB_LCD_FillScreen(uint32_t color);
void UB_LCD_DrawPixel(int16_t xpos, int16_t ypos, uint32_t color);
void UB_LCD_SetMode(LCD_MODE_t mode);
void UB_LCD_SetWindow(uint16_t xstart, uint16_t ystart, uint16_t xend, uint16_t yend);


//--------------------------------------------------------------
#endif // __STM32F4_UB_LCD_N958GB_H
